function [success, message] = validateCombinationsInput(pCombinationsTable)
%VALIDATECOMBINATIONSINPUT Summary of this function goes here
%   Detailed explanation goes here

success = false;
message = 'Unknown error';

%% Validate all columns
if any(isnan(pCombinationsTable.combinationBegin))
    message = 'The "Begin" column contains an invalid value!';
    return;
end

if any(isnan(pCombinationsTable.combinationEnd))
    message = 'The "End" column contains an invalid value!';
    return;
end

if any(strcmp(pCombinationsTable.soundsources, ''))
    message = 'The "Sound Sources" column contains an invalid value!';
    return;
end

if any(isnan(pCombinationsTable.soundspeed1)) ...
        || any(isnan(pCombinationsTable.soundspeed2)) ...
        || any(isnan(pCombinationsTable.soundspeed3))
    message = 'One of the soundspeeds contains an invalid value!';
    return;
end

if any(isempty(pCombinationsTable.trackingMethod)) ...
        || any(strcmp(pCombinationsTable.trackingMethod, ''))
    message = 'You must select a tracking method for all combinations!';
    return;
end

%% Check if interpolation method has been chosen
isInterpolationMethod = artoa.trajectory.isInterpolationMethod(pCombinationsTable.trackingMethod);

if sum(isInterpolationMethod) > 1
    success = false;
    message = 'Using more than one interpolation method is not supported!';
    return;
end

if isInterpolationMethod(end) | isInterpolationMethod(1)
    success = false;
    message = 'The first or last tracking method must not be an interpolation method!';
    return;
end

if sum(~isInterpolationMethod) < 2 & sum(isInterpolationMethod) > 1
    success = false;
    message = 'You require at least two tracking methods that surround an interpolation method!';
    return;
end

if any(diff(find(isInterpolationMethod)) == 1)
    % there are two interpolation methods after each other
    success = false;
    message = 'There are two interpolation methods connected. The trajectory cannot be calculated!';
    return;
end

%% Check if the backward tracking is correct
backwardTracking = pCombinationsTable.backwardTracking;

if backwardTracking(1) & ~all(backwardTracking)
    success = false;
    message = 'If the first combination is to be tracked backwards, all combinations must be set as backward tracking!';
    return;
end

if any(diff(backwardTracking) < 0)
    success = false;
    message = 'It is not possible to mix backward and forward tracking!';
    return;
end

%% Check if there are interpolations methods used but no backward tracking
if sum(isInterpolationMethod) > 0 & ~any(backwardTracking)
    success = false;
    message = 'It is not possible to use an interpolation method without backward tracking!';
    return;
end

success = true;

end

