function [ boolean ] = has_status_and_coordinates( p_profile, p_status, p_max_coord_dist )
%HAS_STATUS_AND_COORDINATES DEPRECATED! Not required anymore! Checks if profile has valid coordinates and given status.
%   Checks if the given profile has the given status as well as valid iridium and
%   gps coordinates. If the distance between iridium and gps exceeds
%   p_max_coord_dist, false is being returned. The distance is being
%   calculated via build in MATLAB distance function.
%
%   Returns: True if all conditions are met. Displays a warning if
%   parameters are wrong, but returns false!
%
%   Parameters:
%   p_profile:          The nemo profile that is being checked.
%   p_status:           Expected xmit_upcast_status.
%   p_max_coord_dist:   Maximum distance in km between iridium and gps.

%% Initializing return variables
boolean = false;

%% Parameter check

if (~isstruct(p_profile) ...
        || ~ischar(p_status) ...
        || ~isnumeric(p_max_coord_dist))
    disp([mfilename ': Wrong parameter. Please check your input. Returning false!']);
end

%% Check status, skip if '' is given
if (~strcmp(p_status, strtrim(p_profile.PROFILE_TECHNICAL_DATA.xmit_upcast_status)) ...
        && ~strcmp(p_status, ''))
    return;
end

%% Check coordinates

if (~nemo.profile.has_gps(p_profile) || ~nemo.profile.has_iridium(p_profile))
    return;
end

% get distance in between
difference = deg2km( ...
    distance('gc', ... % convert to km for easier handling
        [p_profile.SURFACE_GPS_DATA(14), p_profile.SURFACE_GPS_DATA(15)], ...
        [p_profile.IRIDIUM_DATA(1), p_profile.IRIDIUM_DATA(2)] ...
    ) ...
);

if (difference > p_max_coord_dist)
    return;
end

boolean = true;

return;

end

